@@ -27,7 +27,7 @@
 
 from .logger_main import *
 
-__version__: str = "v0.6.8"
+__version__: str = "v0.7.0"
 
 
 set_version(__version__)
@@ -41,6 +41,8 @@ __all__ = [
     "WARNING",
     "ERROR",
     "CRITICAL",
+    "ObjectStateConstant",
+    "PipManage",
     "py_version",
     "__version__",
     "log__init__",
