@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 # Exceptions
 class NoSettings(BaseException):  # PIP管理设置参数为空
     pass
@@ -5,3 +7,7 @@ class NoSettings(BaseException):  # PIP管理设置参数为空
 
 class OverSettings(BaseException):  # PIP管理设置参数过多
     pass
+
+
+class PythonVersionError(BaseException):  # python版本不为3
+    pass
